package java.rmi.activation;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.util.Arrays;
import java.util.Properties;
import java.rmi.MarshalledObject;
import java.io.Serializable;

public final class ActivationGroupDesc implements Serializable
{
    private String className;
    private String location;
    private MarshalledObject<?> data;
    private ActivationGroupDesc.CommandEnvironment env;
    private Properties props;
    private static final long serialVersionUID = -4936225423168276595L;
    
    public ActivationGroupDesc(Properties properties, ActivationGroupDesc.CommandEnvironment commandEnvironment) {
        this(null, null, null, properties, commandEnvironment);
    }
    
    public ActivationGroupDesc(String className, String location, MarshalledObject<?> data, Properties props, ActivationGroupDesc.CommandEnvironment env) {
        this.props = props;
        this.env = env;
        this.data = data;
        this.location = location;
        this.className = className;
    }
    
    public String getClassName() {
        return this.className;
    }
    
    public String getLocation() {
        return this.location;
    }
    
    public MarshalledObject<?> getData() {
        return this.data;
    }
    
    public Properties getPropertyOverrides() {
        return (this.props != null) ? ((Properties)this.props.clone()) : null;
    }
    
    public ActivationGroupDesc.CommandEnvironment getCommandEnvironment() {
        return this.env;
    }
    
    @Override
    public boolean equals(Object o) {
        if ((o instanceof ActivationGroupDesc)) {
            ActivationGroupDesc activationGroupDesc = (ActivationGroupDesc)o;
            return ((this.className != null) ? this.className.equals(activationGroupDesc.className) : (activationGroupDesc.className == null)) && ((this.location != null) ? this.location.equals(activationGroupDesc.location) : (activationGroupDesc.location == null)) && ((this.data != null) ? this.data.equals(activationGroupDesc.data) : (activationGroupDesc.data == null)) && ((this.env != null) ? this.env.equals(activationGroupDesc.env) : (activationGroupDesc.env == null)) && ((this.props != null) ? this.props.equals(activationGroupDesc.props) : (activationGroupDesc.props == null));
        }
        return false;
    }
    
    @Override
    public int hashCode() {
        return ((this.location == null) ? 0 : (this.location.hashCode() << 24)) ^ ((this.env == null) ? 0 : (this.env.hashCode() << 16)) ^ ((this.className == null) ? 0 : (this.className.hashCode() << 8)) ^ ((this.data == null) ? 0 : this.data.hashCode());
    }
    
    public static class CommandEnvironment implements Serializable
    {
        private static final long serialVersionUID = 6165754737887770191L;
        private String command;
        private String[] options;
        
        public CommandEnvironment(String command, String[] array) {
            this.command = command;
            if (array == null) {
                this.options = new String[0];
            }
            else {
                System.arraycopy(array, 0, this.options = new String[array.length], 0, array.length);
            }
        }
        
        public String getCommandPath() {
            return this.command;
        }
        
        public String[] getCommandOptions() {
            return (String[])this.options.clone();
        }
        
        @Override
        public boolean equals(Object o) {
            if ((o instanceof ActivationGroupDesc.CommandEnvironment)) {
                ActivationGroupDesc.CommandEnvironment commandEnvironment = (ActivationGroupDesc.CommandEnvironment)o;
                return ((this.command != null) ? this.command.equals(commandEnvironment.command) : (commandEnvironment.command == null)) && Arrays.equals(this.options, commandEnvironment.options);
            }
            return false;
        }
        
        @Override
        public int hashCode() {
            return (this.command == null) ? 0 : this.command.hashCode();
        }
        
        private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
            objectInputStream.defaultReadObject();
            if (this.options == null) {
                this.options = new String[0];
            }
        }
    }
}
